@@ -25,20 +25,20 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::BiddingStrategy;
-use Google::Ads::GoogleAds::V3::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V3::Resources::Campaign;
-use Google::Ads::GoogleAds::V3::Resources::NetworkSettings;
-use Google::Ads::GoogleAds::V3::Common::TargetSpend;
-use Google::Ads::GoogleAds::V3::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
-use Google::Ads::GoogleAds::V3::Enums::CampaignStatusEnum qw(PAUSED);
+use Google::Ads::GoogleAds::V2::Resources::BiddingStrategy;
+use Google::Ads::GoogleAds::V2::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V2::Resources::Campaign;
+use Google::Ads::GoogleAds::V2::Resources::NetworkSettings;
+use Google::Ads::GoogleAds::V2::Common::TargetSpend;
+use Google::Ads::GoogleAds::V2::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V2::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
+use Google::Ads::GoogleAds::V2::Enums::CampaignStatusEnum qw(PAUSED);
 use
-  Google::Ads::GoogleAds::V3::Services::BiddingStrategyService::BiddingStrategyOperation;
+  Google::Ads::GoogleAds::V2::Services::BiddingStrategyService::BiddingStrategyOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V2::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V2::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V2::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -66,7 +66,7 @@ sub use_portfolio_bidding_strategy {
 
   my $campaign_budget_resource_name =
     $campaign_budget_id
-    ? Google::Ads::GoogleAds::V3::Utils::ResourceNames::campaign_budget(
+    ? Google::Ads::GoogleAds::V2::Utils::ResourceNames::campaign_budget(
     $customer_id, $campaign_budget_id)
     : create_shared_campaign_buget($api_client, $customer_id);
 
@@ -85,9 +85,9 @@ sub create_bidding_strategy {
 
   # Create a portfolio bidding strategy.
   my $portfolio_bidding_strategy =
-    Google::Ads::GoogleAds::V3::Resources::BiddingStrategy->new({
+    Google::Ads::GoogleAds::V2::Resources::BiddingStrategy->new({
       name        => "Maximize Clicks #" . uniqid(),
-      targetSpend => Google::Ads::GoogleAds::V3::Common::TargetSpend->new({
+      targetSpend => Google::Ads::GoogleAds::V2::Common::TargetSpend->new({
           cpcBidCeilingMicros => 2000000,
           targetSpendMicros   => 20000000
         }
@@ -96,7 +96,7 @@ sub create_bidding_strategy {
 
   # Create a bidding strategy operation.
   my $bidding_strategy_operation =
-    Google::Ads::GoogleAds::V3::Services::BiddingStrategyService::BiddingStrategyOperation
+    Google::Ads::GoogleAds::V2::Services::BiddingStrategyService::BiddingStrategyOperation
     ->new({
       create => $portfolio_bidding_strategy
     });
@@ -110,7 +110,7 @@ sub create_bidding_strategy {
   my $bidding_strategy_resource_name =
     $bidding_strategy_response->{results}[0]{resourceName};
 
-  printf "Created portfolio bidding strategy with resource name: '%s'.\n",
+  printf "Created portfolio bidding strategy with resource name: %s.\n",
     $bidding_strategy_resource_name;
 
   return $bidding_strategy_resource_name;
@@ -122,7 +122,7 @@ sub create_shared_campaign_buget {
 
   # Create a shared budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V3::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V2::Resources::CampaignBudget->new({
       name           => "Shared Interplanetary Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       # Set the amount of budget.
@@ -133,7 +133,7 @@ sub create_shared_campaign_buget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V2::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -144,7 +144,7 @@ sub create_shared_campaign_buget {
   my $campaign_budget_resource_name =
     $campaign_budget_response->{results}[0]{resourceName};
 
-  printf "Created a shared budget with resource name: '%s'.\n",
+  printf "Created a shared budget with resource name: %s.\n",
     $campaign_budget_resource_name;
 
   return $campaign_budget_resource_name;
@@ -159,7 +159,7 @@ sub create_campaign_with_bidding_strategy {
   ) = @_;
 
   # Create a search campaign.
-  my $campaign = Google::Ads::GoogleAds::V3::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V2::Resources::Campaign->new({
       name                   => "Interplanetary Cruise #" . uniqid(),
       advertisingChannelType => SEARCH,
       # Recommendation: Set the campaign to PAUSED when creating it to stop
@@ -168,7 +168,7 @@ sub create_campaign_with_bidding_strategy {
       status => PAUSED,
       # Configures the campaign network options.
       networkSettings =>
-        Google::Ads::GoogleAds::V3::Resources::NetworkSettings->new({
+        Google::Ads::GoogleAds::V2::Resources::NetworkSettings->new({
           targetGoogleSearch   => "true",
           targetSearchNetwork  => "true",
           targetContentNetwork => "true"
@@ -181,7 +181,7 @@ sub create_campaign_with_bidding_strategy {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V2::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
@@ -191,7 +191,7 @@ sub create_campaign_with_bidding_strategy {
 
   my $campaign_resource_name = $campaign_response->{results}[0]{resourceName};
 
-  printf "Created a campaign with resource name: '%s'.\n",
+  printf "Created a campaign with resource name: %s.\n",
     $campaign_resource_name;
 }
 
@@ -201,7 +201,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
