@@ -26,10 +26,10 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V3::Resources::AdGroup;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum qw(PAUSED);
-use Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+use Google::Ads::GoogleAds::V2::Resources::AdGroup;
+use Google::Ads::GoogleAds::V2::Enums::AdGroupStatusEnum qw(PAUSED);
+use Google::Ads::GoogleAds::V2::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V2::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -51,9 +51,9 @@ sub update_ad_group {
   my ($api_client, $customer_id, $ad_group_id, $bid_micro_amount) = @_;
 
   # Create an ad group with the proper resource name and any other changes.
-  my $ad_group = Google::Ads::GoogleAds::V3::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V2::Resources::AdGroup->new({
       resourceName =>
-        Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+        Google::Ads::GoogleAds::V2::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
         ),
       status       => PAUSED,
@@ -63,7 +63,7 @@ sub update_ad_group {
   # Create an ad group operation for update, using the FieldMasks utility
   # to derive the update mask.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation->new(
+    Google::Ads::GoogleAds::V2::Services::AdGroupService::AdGroupOperation->new(
     {
       update     => $ad_group,
       updateMask => all_set_fields_of($ad_group)});
@@ -73,7 +73,7 @@ sub update_ad_group {
       customerId => $customer_id,
       operations => [$ad_group_operation]});
 
-  printf "Updated ad group with resource name: '%s'.\n",
+  printf "Updated ad group with resource name: %s.\n",
     $ad_group_response->{results}[0]{resourceName};
 
   return 1;
@@ -85,7 +85,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
