@@ -40,7 +40,7 @@ use constant POST => "POST";
 # Class::Std-style attributes. Need to be kept in the same line.
 # These need to go in the same line for older Perl interpreters to understand.
 my %api_client_of : ATTR(:name<api_client> :default<>);
-my %__lwp_agent_of : ATTR(:name<__lwp_agent> :default<>);
+my %__user_agent_of : ATTR(:name<__user_agent> :default<>);
 my %__json_coder_of : ATTR(:name<__json_coder> :default<>);
 
 # Automatically called by Class::Std after the values for all the attributes
@@ -48,7 +48,7 @@ my %__json_coder_of : ATTR(:name<__json_coder> :default<>);
 sub START {
   my ($self, $ident) = @_;
 
-  $__lwp_agent_of{$ident} ||= LWP::UserAgent->new();
+  $__user_agent_of{$ident} ||= LWP::UserAgent->new();
   # The 'pretty' attribute should be enabled for more readable form in the log.
   # The 'convert_blessed' attributed should be enabled to convert blessed objects.
   $__json_coder_of{$ident} ||= JSON::XS->new->utf8->pretty->convert_blessed;
@@ -56,9 +56,7 @@ sub START {
 
 # Sends a HTTP request to Google Ads API server and handles the response.
 sub call {
-  my ($self, $http_method, $request_path, $request_body, $response_type,
-    $content_callback)
-    = @_;
+  my ($self, $http_method, $request_path, $request_body, $response_type) = @_;
 
   my $api_client = $self->get_api_client();
 
@@ -67,11 +65,11 @@ sub call {
   ##############################################################################
   if ($http_method eq GET) {
     # HTTP GET request scenarios:
-    #  GET: v3/customers:listAccessibleCustomers
-    #  GET: v3/{+resourceName}
-    #  GET: v3/{+resourceName}:listResults
-    #  GET: v3/customers/{+customerId}/paymentsAccounts
-    #  GET: v3/customers/{+customerId}/merchantCenterLinks
+    #  GET: v2/customers:listAccessibleCustomers
+    #  GET: v2/{+resourceName}
+    #  GET: v2/{+resourceName}:listResults
+    #  GET: v2/customers/{+customerId}/paymentsAccounts
+    #  GET: v2/customers/{+customerId}/merchantCenterLinks
     $request_path = expand_path_template($request_path, $request_body);
 
     # GET: When the $request_body is a hash reference, use the path parameters
@@ -86,13 +84,13 @@ sub call {
     }
   } elsif ($http_method eq POST) {
     # HTTP POST request scenarios:
-    #  POST: v3/geoTargetConstants:suggest
-    #  POST: v3/googleAdsFields:search
-    #  POST: v3/customers/{+customerId}/googleAds:search
-    #  POST: v3/customers/{+customerId}/campaigns:mutate
-    #  POST: v3/{+keywordPlan}:generateForecastMetrics
-    #  POST: v3/{+campaignDraft}:promote
-    #  POST: v3/{+resourceName}:addOperations
+    #  POST: v2/geoTargetConstants:suggest
+    #  POST: v2/googleAdsFields:search
+    #  POST: v2/customers/{+customerId}/googleAds:search
+    #  POST: v2/customers/{+customerId}/campaigns:mutate
+    #  POST: v2/{+keywordPlan}:generateForecastMetrics
+    #  POST: v2/{+campaignDraft}:promote
+    #  POST: v2/{+resourceName}:addOperations
 
     # POST: Retain the 'customerId' variable in the $request_body hash
     # reference after the $request_path is expanded.
@@ -103,7 +101,7 @@ sub call {
     $request_body->{customerId} = $customer_id if defined $customer_id;
   } else {
     # Other HTTP request scenarios:
-    #  DELETE: v3/{+name} for OperationService
+    #  DELETE: v2/{+name} for OperationService
     $request_path = expand_path_template($request_path, $request_body);
   }
 
@@ -139,38 +137,19 @@ sub call {
 
   utf8::is_utf8 $http_request and utf8::encode $http_request;
 
-  my $lwp_agent = $self->get___lwp_agent();
+  my $user_agent = $self->get___user_agent();
 
-  # Set up http timeout and proxy for the lwp agent.
-  my $http_timeout = $api_client->get_http_timeout();
-  $lwp_agent->timeout(
-      $http_timeout
-    ? $http_timeout
-    : Google::Ads::GoogleAds::Constants::DEFAULT_HTTP_TIMEOUT
-  );
+  # Set up timeout and proxy for the user agent.
+  $user_agent->timeout(Google::Ads::GoogleAds::Constants::DEFAULT_LWP_TIMEOUT);
   my $proxy = $api_client->get_proxy();
   $proxy
-    ? $lwp_agent->proxy(['http', 'https'], $proxy)
-    : $lwp_agent->env_proxy;
+    ? $user_agent->proxy(['http', 'https'], $proxy)
+    : $user_agent->env_proxy;
 
   # Keep track of the last sent HTTP request.
   $api_client->set_last_request($http_request);
 
-  # Send HTTP request with optional content callback handler (for search stream).
-  my $http_response = undef;
-  if ($content_callback) {
-    $http_response = $lwp_agent->request($http_request, $content_callback);
-    # The callback handler is not invoked when the response status is error.
-    if ($http_response->is_error) {
-      # The error response content returned by the search stream interface is
-      # enclosed in square brackets, deviating from normal GoogleAdsException.
-      # Remove the leading and trailing square brackets in the response content,
-      # to make it operable in the subsequent steps (logging, exception handling).
-      $http_response->content($http_response->decoded_content =~ s/^\[|\]$//gr);
-    }
-  } else {
-    $http_response = $lwp_agent->request($http_request);
-  }
+  my $http_response = $user_agent->request($http_request);
 
   # Keep track of the last received HTTP response.
   $api_client->set_last_response($http_response);
@@ -197,8 +176,7 @@ sub call {
   ##############################################################################
   # Step 4: Return the decoded object or exception from the response content.
   ##############################################################################
-  my $response_body =
-    $response_content ? $json_coder->decode($response_content) : {};
+  my $response_body = $json_coder->decode($response_content);
 
   if ($http_response->is_success) {
     # Bless the JSON format response to the response type class.
@@ -218,15 +196,12 @@ sub _get_http_headers {
   my ($self) = @_;
 
   my $api_client = $self->get_api_client();
-  my $user_agent = $api_client->get_user_agent();
 
   my $headers = [
     "Content-Type",
     "application/json; charset=utf-8",
     "user-agent",
-    $user_agent
-    ? $user_agent
-    : Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
+    Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
     "x-goog-api-client",
     Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
     "developer-token",
@@ -256,13 +231,13 @@ AdGroupService, etc.
 
   use Google::Ads::GoogleAds::Client;
 
-  my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+  my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
 
   my $campaign_service = $api_client->CampaignService();
 
 =head1 ATTRIBUTES
 
-Each service instance is initialized by L<Google::Ads::GoogleAds::Client>, and
+Each service instance is initialized by L<Google::Ads::GoogleAds::Client>,and
 these attributes are set automatically.
 
 Alternatively, there is a get_ and set_ method associated with each attribute
@@ -291,7 +266,7 @@ I<http_method>: The HTTP request method, e.g. GET, POST.
 
 =item *
 
-I<request_path>: The relative request URL which may contain wildcards to expand,
+I<request_path>: The relative request URL which may contains wildcard to expand,
 e.g. {+resourceName}, {+customerId}.
 
 =item *
@@ -306,16 +281,14 @@ be encoded into JSON string for a HTTP POST request. Should be C<undef> for GET
 
 =item *
 
-I<response_type>: The class name of the expected response. An instance of this class
+I<response_type>: The class name of the expected response. A instance of this class
 will be returned if the request succeeds.
 
-I<content_callback>: The optional streaming content callback method.
-
 =back
 
 =head3 Returns
 
-An instance of the class defined by the C<response_type> argument, or a
+A instance of the class defined by the C<response_type> argument, or a
 L<Google::Ads::GoogleAds::GoogleAdsException> object if an error has occurred at the
 server side by default. However if the C<die_on_faults> flag is set to true in
 L<Google::Ads::GoogleAds::Client>, the service will issue a die() with error
@@ -332,6 +305,8 @@ in the method of L<Google::Ads::GoogleAds::Common::OAuth2BaseHandler/prepare_req
 The basic HTTP headers including Content-Type, developer-token and login_customer_id
 - if needed.
 
+=cut
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2019 Google LLC
