@@ -11,17 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# The main interface to the Google Ads API. It takes care of handling your API
-# credentials, and exposes all of the underlying services that make up the
-# Google Ads API.
 
 package Google::Ads::GoogleAds::Client;
 
 use strict;
 use warnings;
 use version;
-our $VERSION = qv("0.3.1");
+our $VERSION = qv("2.1.0");
 
 use Google::Ads::GoogleAds::OAuth2ApplicationsHandler;
 use Google::Ads::GoogleAds::Logging::GoogleAdsLogger;
@@ -35,10 +31,8 @@ use constant AUTH_HANDLERS_ORDER          => (OAUTH_2_APPLICATIONS_HANDLER);
 # These need to go in the same line for older Perl interpreters to understand.
 my %developer_token_of : ATTR(:name<developer_token> :default<>);
 my %login_customer_id_of : ATTR(:name<login_customer_id> :default<>);
-my %service_address_of : ATTR(:name<service_address> :default<>);
-my %user_agent_of : ATTR(:name<user_agent> :default<>);
 my %proxy_of : ATTR(:name<proxy> :default<>);
-my %http_timeout_of : ATTR(:name<http_timeout> :default<>);
+my %service_address_of : ATTR(:name<service_address> :default<>);
 my %version_of : ATTR(:name<version> :default<>);
 my %die_on_faults_of : ATTR(:name<die_on_faults> :default<0>);
 
@@ -70,7 +64,6 @@ sub START {
     $developer_token_of{$ident}   ||= $properties{developerToken};
     $login_customer_id_of{$ident} ||= $properties{loginCustomerId};
     $service_address_of{$ident}   ||= $properties{serviceAddress};
-    $user_agent_of{$ident}        ||= $properties{userAgent};
     $proxy_of{$ident}             ||= $properties{proxy};
   }
 
@@ -78,8 +71,6 @@ sub START {
   # parameters to new() nor in the properties file.
   $service_address_of{$ident} ||=
     Google::Ads::GoogleAds::Constants::DEFAULT_SERVICE_ADDRESS;
-  $http_timeout_of{$ident} ||=
-    Google::Ads::GoogleAds::Constants::DEFAULT_HTTP_TIMEOUT;
   $version_of{$ident} ||=
     Google::Ads::GoogleAds::Constants::DEFAULT_API_VERSION;
 
@@ -224,19 +215,19 @@ Google::Ads::GoogleAds::Client
 
   use Google::Ads::GoogleAds::Client;
 
-  my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+  my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
 
   my $customer_id = "1234567890";
 
   my $query = "SELECT campaign.id, campaign.name FROM campaign";
 
-  my $response = $api_client->GoogleAdsService()->search({
+  my $result = $api_client->GoogleAdsService()->search({
     customer_id => $customer_id,
     query       => $query,
     pageSize    => PAGE_SIZE
   });
 
-  foreach my $row (@{$response->{results}}) {
+  foreach my $row (@{$result->{results}}) {
     # Do something with the results
   }
 
@@ -252,7 +243,8 @@ wrong order.
 
 =head1 ATTRIBUTES
 
-Each of these attributes can be set via Google::Ads::GoogleAds::Client->new().
+Each of these attributes can be set via
+Google::Ads::GoogleAds::Client->new().
 
 Alternatively, there is a get_ and set_ method associated with each attribute
 for retrieving or setting them dynamically. For example, the set_login_customer_id()
@@ -266,7 +258,7 @@ account.
 
 The value should be a character string assigned to you by Google. You can
 apply for a Developer Token by following the instructions at
-L<https://developers.google.com/google-ads/api/docs/first-call/dev-token>.
+L<https://developers.google.com/google-ads/api/docs/first-call/dev-token>
 
 =head2 login_customer_id
 
@@ -274,21 +266,13 @@ This is the customer ID of the authorized customer to use in the request, withou
 hyphens. If your access to the customer account is through a manager account,
 this attribute is required and must be set to the customer ID of the manager account.
 
-=head2 service_address
-
-The Google Ads API service address.
-
-=head2 user_agent
-
-The user-agent request header used to identify this application.
-
 =head2 proxy
 
 The proxy server URL to be used for internet connectivity.
 
-=head2 http_timeout
+=head2 service_address
 
-The HTTP timeout value in seconds.
+The Google Ads API service address.
 
 =head2 version
 
@@ -385,7 +369,7 @@ die() with an error message describing the failure.
 This module supports two approaches for handling API faults (i.e. errors
 returned by the underlying REST API service).
 
-One approach is to issue a die() with a description of the error when an API
+One approach is to issue a die() with a description of the error when a API
 fault occurs. This die() would ideally be contained within an eval { }; block,
 thereby emulating try { } / catch { } exception functionality in other
 languages.
@@ -402,7 +386,7 @@ The default value is false, i.e. you must explicitly check for faults.
 
 =head3 Parameters
 
-A true value will cause this module to die() when an API fault occurs.
+A true value will cause this module to die() when a API fault occurs.
 
 A false value will suppress this die(). This is the default behavior.
 
@@ -439,8 +423,8 @@ instance is set to die() on API faults.
 
 The client object contains a method for each service provided by the Google Ads
 API. For example it can be invoked as $api_client->AdGroupService() and it will
-return an object of type L<Google::Ads::GoogleAds::V3::Services::AdGroupService>
-when using version V3 of the API.
+return an object of type L<Google::Ads::GoogleAds::V2::Services::AdGroupService>
+when using version V2 of the API.
 
 For a list of all the available services please refer to
 L<https://developers.google.com/google-ads/api/docs> and for code samples on
